==> mysql-5.6.14.tar.gz: mysql-5.6.14/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/TransactionImpl.java <==
/*
   Copyright 2010 Sun Microsystems, Inc.
   All rights reserved. Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core;


import com.mysql.clusterj.Transaction;

import com.mysql.clusterj.core.util.I18NHelper;
import com.mysql.clusterj.core.util.Logger;
import com.mysql.clusterj.core.util.LoggerFactoryService;

public class TransactionImpl implements Transaction {

    /** My logger */
    static final I18NHelper local = I18NHelper.getInstance(TransactionImpl.class);

    /** My logger */
    static final Logger logger = LoggerFactoryService.getFactory().getInstance(TransactionImpl.class);

    /** My session. */
    protected SessionImpl session;

    TransactionImpl(SessionImpl session) {
        this.session = session;
    }

    public void begin() {
        session.begin();
    }

    public void commit() {
        session.commit();
    }

    public void rollback() {
        session.rollback();
    }

    public boolean isActive() {
        return session.isActive();
    }

    public void setRollbackOnly() {
        session.setRollbackOnly();
    }

    public boolean getRollbackOnly() {
        return session.getRollbackOnly();
    }

}

==> mysql-5.6.51.tar.gz: mysql-5.6.51/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/TransactionImpl.java <==
/*
   Copyright 2010 Sun Microsystems, Inc.
   All rights reserved. Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core;


import com.mysql.clusterj.Transaction;

import com.mysql.clusterj.core.util.I18NHelper;
import com.mysql.clusterj.core.util.Logger;
import com.mysql.clusterj.core.util.LoggerFactoryService;

public class TransactionImpl implements Transaction {

    /** My logger */
    static final I18NHelper local = I18NHelper.getInstance(TransactionImpl.class);

    /** My logger */
    static final Logger logger = LoggerFactoryService.getFactory().getInstance(TransactionImpl.class);

    /** My session. */
    protected SessionImpl session;

    TransactionImpl(SessionImpl session) {
        this.session = session;
    }

    public void begin() {
        session.begin();
    }

    public void commit() {
        session.commit();
    }

    public void rollback() {
        session.rollback();
    }

    public boolean isActive() {
        return session.isActive();
    }

    public void setRollbackOnly() {
        session.setRollbackOnly();
    }

    public boolean getRollbackOnly() {
        return session.getRollbackOnly();
    }

}
